# textmodule.dllについて
`textmodule.dll`は、Lua（ANSI）で`string.gsub`などを使用すると、不具合が発生する問題を解決したモジュールです。

具体的には、以下のようなフローで処理しています。  
1. Luaからマルチバイト文字列を`textmodule.dll`が受け取る。
2. `textmodule.dll`上でワイド文字列に変換
3. 文字列処理を行う
4. `textmodule.dll`上でマルチバイト文字列に変換
5. Luaに返す

## 引数・返り値について
文字列の位置は、1から順に数えます。  
例：`"abcdefg"`の`c`は3文字目  

文字数は、ワイド文字列の状態で計算します。  
例：`あいうえお`の長さは5  

## 更新履歴
- [2021-06-04] 0.0.1
- [2021-06-19] 0.0.2


## 関数
### `start, end = find(string, pattern)`
`string`にある`pattern`を検索し、その開始位置と終了位置を返します。  
ただし、`pattern`は正規表現です。  

### `t = sub(string, start, end)`
`string`の`start`文字目から`end`文字目までを返します。  
`end`を省略した場合、`start`文字目～最後までを切り抜きます。  

### `t = gsub(string, pattern, repl, num)`
`string`にある`pattern`を`repl`で置換します。  
ただし、`pattern`は正規表現です。  
`num`で置換の回数を指定しますが、指定しない場合は`1`になります。  

### `l = len(string)`
`string`の長さを返します。  
ワイド文字列においての長さであるため、Lua標準の`string.len`とは値が異なります。  

### `t = reverse(string)`
`string`を逆順にした文字列を返します。  
例：「あいうえお」→「おえいうあ」  

### `t = upper(string)`
`string`内の英語小文字を大文字に変換して返します。

### `t = lower(string)`
`string`内の英語大文字を小文字に変換して返します。  

### `t = match(string, pattern, num)`
`string`と`pattern`を比較して、最初にマッチした部分を返します。  
ただし、`pattern`は正規表現です。  
`num`で検索を開始する位置を指定できますが、指定しない場合は`1`になります。  

### `t = byte(string, i, j)`
文字列`string`の`i`文字目から`j`文字目の文字コードを返します。  
文字コードの数値は、ワイド文字列の状態で取得します。  
`i`を指定しない場合は、`1`になります。  
`j`を指定しない場合は、`i`と同じ値になります。

### `t = char(i1, i2, ...)`
0個以上の数値 `i1, i2 ...` を指定すると、 各文字が与えられた引数と等しい内部コードを持ち、長さが引数の数に等しい、文字列を返します。   
文字コードの数値は、ワイド文字列の状態で取得します。  

### `func = gmatch(string, pattern)`
`string`から`pattern`に当てはまる部分を次々と返すような、イテレータ関数を返します。
ただし、`pattern`は正規表現です。   

### `t = hiragana(string)`
`string`内のカタカナをひらがなに変換して、返します。  

### `t = katakana(string)`
`string`内のひらがなをカタカナに変換して、返します。  

### `t = halfwidth(m)`
`string`内の全角文字を半角文字に変換して、返します。  
`m`（ブーリアン値）を指定すると、全角スペースを半角スペースに変換するかどうかを指定できます。
`m`を指定しない場合は、`true`となります。  

### `t = fullwidth(m)`
`string`内の半角文字を全角文字に変換して、返します。  
`m`（ブーリアン値）を指定すると、半角スペースを全角スペースに変換するかどうかを指定できます。
`m`を指定しない場合は、`true`となります。  
